@@ -15,6 +15,8 @@ sub new {
                 $self->meta->get_all_events,
                 STARTALL => 'STARTALL',
                 _stop    => 'STOPALL',
+                _child   => 'CHILD',
+                _parent  => 'PARENT',
             },
         ],
         args => [$self],
@@ -36,6 +38,7 @@ sub call { my $self = shift; POE::Kernel->call( $self->get_session_id, @_ ) }
 
 sub STARTALL {
     my ( $self, @params ) = @_;
+    $params[4] = pop @params;
     foreach
         my $method ( reverse $self->meta->find_all_methods_by_name('START') )
     {
@@ -51,8 +54,10 @@ sub STOPALL {
     }
 }
 
-sub START { }
-sub STOP  { }
+sub START  { }
+sub STOP   { }
+sub CHILD  { }
+sub PARENT { }
 
 # __PACKAGE__->meta->add_method( _stop => sub { POE::Kernel->call('STOP') } );
 
